==> v2.3.0.tar.gz: info_tren/lib/pages/train_info_page/view_train/train_info_material_DisplayTrainStation.dart <==
import 'package:flutter/material.dart';
import 'package:info_tren/models/train_data.dart';
import 'package:info_tren/pages/train_info_page/view_train/train_info_material.dart' show isSmallScreen;

class DisplayTrainStation extends StatelessWidget {
  final Station station;

  DisplayTrainStation({required this.station});

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: const EdgeInsets.all(2),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            Row(
              mainAxisSize: MainAxisSize.max,
              children: <Widget>[
                Builder(
                  builder: (context) {
                    final delay = station.departure?.status?.delay ?? station.arrival?.status?.delay;
                    final real = station.departure?.status?.real ?? station.arrival?.status?.real;

                    final isDelayed = delay != null && delay > 0 && real == true;
                    final isOnTime = delay != null && delay <= 0 && real == true;
                    final isNotScheduled = false;

                    return KmBadge(
                      station: station,
                      isNotScheduled: isNotScheduled,
                      isDelayed: isDelayed,
                      isOnTime: isOnTime,
                    );
                  }
                ),
                Expanded(
                  child: Title(
                    station: station,
                  ),
                ),
              ],
            ),
            Time(
              station: station,
            ),
            Delay(
              station: station,
            ),
          ],
        ),
      ),
    );
  }
}

class KmBadge extends StatelessWidget {
  final Station station;
  final bool isNotScheduled;
  final bool isOnTime;
  final bool isDelayed;

  KmBadge({
    required this.station,
    this.isNotScheduled = false,
    this.isOnTime = false,
    this.isDelayed = false,
  });

  @override
  Widget build(BuildContext context) {
    Color foregroundColor = Colors.white70;
    Color? backgroundColor;

    if (isNotScheduled) {
      foregroundColor = Colors.orange.shade300;
      backgroundColor = Colors.orange.shade900.withOpacity(0.3);
    }
    else if (isOnTime) {
      foregroundColor = Colors.green.shade300;
      backgroundColor = Colors.green.shade900.withOpacity(0.3);
    }
    else if (isDelayed) {
      foregroundColor = Colors.red.shade300;
      backgroundColor = Colors.red.shade900.withOpacity(0.3);
    }

    return Padding(
      padding: const EdgeInsets.all(8),
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          border: Border.all(
            width: 2,
            color: foregroundColor,
          ),
          color: backgroundColor,
        ),
        width: isSmallScreen(context) ? 42 : 48,
        height: isSmallScreen(context) ? 42 : 48,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Expanded(
              child: Center(
                child: Text(
                  station.km.toString(),
                  style: Theme.of(context).textTheme.bodyText2?.copyWith(
                    fontSize: isSmallScreen(context) ? 16 : 20,
                    fontWeight: MediaQuery.of(context).boldText ? FontWeight.w400 : FontWeight.w200,
                    color: MediaQuery.of(context).boldText ? Colors.white70 : foregroundColor,
                  ),
                  textAlign: TextAlign.center,
                ),
              ),
            ),
            Text(
              "km",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                fontSize: 10,
                color: MediaQuery.of(context).boldText ? Colors.white70 : foregroundColor,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

class Title extends StatelessWidget {
  final Station station;

  Title({
    required this.station
  });

  @override
  Widget build(BuildContext context) {
    return  Text(
      station.name,
      style: Theme.of(context).textTheme.bodyText2?.copyWith(
        fontSize: isSmallScreen(context) ? 18 : 22,
        fontWeight: MediaQuery.of(context).boldText ? FontWeight.w500 : FontWeight.w300,
        // fontStyle: items[1] == "ONI" ? FontStyle.italic : FontStyle.normal,
      ),
      textAlign: TextAlign.center,
    );
  }
}

class Time extends StatelessWidget {
  final Station station;

  Time({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival == null) {
      // Plecare
      return DepartureTime(
        station: station,
        firstStation: true,
      );
    }

    if (station.departure == null) {
      // Sosire
      return ArrivalTime(
        station: station,
        finalStation: true,
      );
    }

    return Row(
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        Text(
          "→",
          style: Theme.of(context).textTheme.bodyText2?.copyWith(
            fontSize: isSmallScreen(context) ? 18 : 22,
          ),
        ),
        Container(width: 2,),
        ArrivalTime(station: station,),
        Expanded(child: Container(),),
        StopTime(station: station,),
        Expanded(child: Container(),),
        DepartureTime(station: station,),
        Container(width: 2,),
        Text(
          "→",
          style: Theme.of(context).textTheme.bodyText2?.copyWith(
            fontSize: isSmallScreen(context) ? 18 : 22,
          ),
        ),
      ],
    );
  }
}

class ArrivalTime extends StatelessWidget {
  final Station station;
  final bool finalStation;

  ArrivalTime({
    required this.station,
    this.finalStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival == null) {
      return Container();
    }
    if (finalStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Text(
            "→",
            style: Theme.of(context).textTheme.bodyText2?.copyWith(
              fontSize: isSmallScreen(context) ? 18 : 22,
            ),
          ),
          Container(width: 2,),
          Text("sosire la "),
          ArrivalTime(station: station,),
          Expanded(child: Container(),),
        ],
      );
    }
    else {
      final delay = station.arrival!.status?.delay ?? 0;
      final time = station.arrival!.scheduleTime;

      if (delay == 0) {
        return Text("$time");
      }
      else if (delay > 0) {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.red.shade300,
              ),
            ),
          ],
        );
      }
      else {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.green.shade300,
              ),
            ),
          ],
        );
      }
    }
  }
}

class StopTime extends StatelessWidget {
  final Station station;

  StopTime({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: <Widget>[
        Text(
          "staționează pentru",
          textAlign: TextAlign.center,
        ),
        Builder(
          builder: (context) {
            int stopsForInt = station.stoppingTime!;
            if (stopsForInt == 1) {
              return Text(
                "1 minut",
                textAlign: TextAlign.center,
              );
            }
            else if (stopsForInt < 20) {
              return Text(
                "${station.stoppingTime} minute",
                textAlign: TextAlign.center,
              );
            }
            else {
              return Text(
                "${station.stoppingTime} de minute",
                textAlign: TextAlign.center,
              );
            }
          },
        )
      ],
    );
  }
}

class DepartureTime extends StatelessWidget {
  final Station station;
  final bool firstStation;

  DepartureTime({
    required this.station,
    this.firstStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (station.departure == null) {
      return Container();
    }
    if (firstStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Expanded(child: Container(),),
          Text("plecare la "),
          DepartureTime(station: station,),
          Container(width: 2,),
          Text(
            "→",
            style: Theme.of(context).textTheme.bodyText2?.copyWith(
              fontSize: 22,
            ),
          ),
        ],
      );
    }
    else {
      final delay = station.departure!.status?.delay ?? 0;
      final time = station.departure!.scheduleTime;

      if (delay == 0) {
        return Text("$time");
      }
      else if (delay > 0) {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.red.shade300,
              ),
            ),
          ],
        );
      }
      else {
        final splits = time.split(":").map((s) => int.parse(s)).toList();

        final now = DateTime.now();
        final oldDate = DateTime(now.year, now.month, now.day, splits[0], splits[1]);
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.green.shade300,
              ),
            ),
          ],
        );
      }
    }
  }
}


class Delay extends StatelessWidget {
  final Station station;

  Delay({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival?.status == null && station.departure?.status == null) {
      return Container();
    }
    var delay = station.arrival?.status?.delay;
    if (station.departure?.status?.real == true) {
      delay = station.departure?.status?.delay;
    }

    if (delay == 0 || delay == null) return Container();
    else if (delay > 0) {
      return Text(
        "$delay minute întârziere",
        style: Theme.of(context).textTheme.bodyText2?.copyWith(
          color: Colors.red.shade300,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }
    else if (delay < 0) {
      return Text(
        "${-delay} minute mai devreme",
        style: Theme.of(context).textTheme.bodyText2?.copyWith(
          color: Colors.green.shade300,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }

    return Container();
  }
}

==> v2.4.0.tar.gz: info_tren/lib/pages/train_info_page/view_train/train_info_material_DisplayTrainStation.dart <==
import 'package:flutter/material.dart';
import 'package:info_tren/models/train_data.dart';
import 'package:info_tren/pages/train_info_page/view_train/train_info_material.dart' show isSmallScreen;

class DisplayTrainStation extends StatelessWidget {
  final Station station;

  DisplayTrainStation({required this.station});

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: const EdgeInsets.all(2),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            Row(
              mainAxisSize: MainAxisSize.max,
              children: <Widget>[
                Builder(
                  builder: (context) {
                    final departureStatus = station.departure?.status;
                    final arrivalStatus = station.arrival?.status;
                    int delay;
                    bool real;
                    if (departureStatus == null) {
                      delay = arrivalStatus?.delay ?? 0;
                      real = arrivalStatus?.real ?? false;
                    }
                    else if (arrivalStatus == null) {
                      delay = departureStatus.delay;
                      real = departureStatus.real;
                    }
                    else {
                      delay = departureStatus.delay;
                      real = departureStatus.real;
                      if (!real && arrivalStatus.real) {
                        delay = arrivalStatus.delay;
                        real = arrivalStatus.real;
                      }
                    }

                    final isDelayed = delay > 0 && real == true;
                    final isOnTime = delay <= 0 && real == true;
                    final isNotScheduled = false;

                    return Badge(
                      text: station.km.toString(),
                      caption: 'km',
                      isNotScheduled: isNotScheduled,
                      isDelayed: isDelayed,
                      isOnTime: isOnTime,
                    );
                  }
                ),
                Expanded(
                  child: Title(
                    station: station,
                  ),
                ),
                if (station.platform == null)
                  Container(width: isSmallScreen(context) ? 42 : 48, height: isSmallScreen(context) ? 42 : 48,)
                else
                  Badge(text: station.platform!, caption: 'linia',),
              ],
            ),
            Time(
              station: station,
            ),
            Delay(
              station: station,
            ),
          ],
        ),
      ),
    );
  }
}

class Badge extends StatelessWidget {
  final String text;
  final String caption;
  final bool isNotScheduled;
  final bool isOnTime;
  final bool isDelayed;

  Badge({
    required this.text,
    required this.caption,
    this.isNotScheduled = false,
    this.isOnTime = false,
    this.isDelayed = false,
  });

  @override
  Widget build(BuildContext context) {
    Color foregroundColor = Colors.white70;
    Color? backgroundColor;

    if (isNotScheduled) {
      foregroundColor = Colors.orange.shade300;
      backgroundColor = Colors.orange.shade900.withOpacity(0.3);
    }
    else if (isOnTime) {
      foregroundColor = Colors.green.shade300;
      backgroundColor = Colors.green.shade900.withOpacity(0.3);
    }
    else if (isDelayed) {
      foregroundColor = Colors.red.shade300;
      backgroundColor = Colors.red.shade900.withOpacity(0.3);
    }

    return Padding(
      padding: const EdgeInsets.all(8),
      child: Container(
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          border: Border.all(
            width: 2,
            color: foregroundColor,
          ),
          color: backgroundColor,
        ),
        width: isSmallScreen(context) ? 42 : 48,
        height: isSmallScreen(context) ? 42 : 48,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Expanded(
              child: Center(
                child: Text(
                  text,
                  style: Theme.of(context).textTheme.bodyText2?.copyWith(
                    fontSize: isSmallScreen(context) ? 16 : 20,
                    fontWeight: MediaQuery.of(context).boldText ? FontWeight.w400 : FontWeight.w200,
                    color: MediaQuery.of(context).boldText ? Colors.white70 : foregroundColor,
                  ),
                  textAlign: TextAlign.center,
                ),
              ),
            ),
            Text(
              caption,
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                fontSize: 10,
                color: MediaQuery.of(context).boldText ? Colors.white70 : foregroundColor,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

class Title extends StatelessWidget {
  final Station station;

  Title({
    required this.station
  });

  @override
  Widget build(BuildContext context) {
    return  Text(
      station.name,
      style: Theme.of(context).textTheme.bodyText2?.copyWith(
        fontSize: isSmallScreen(context) ? 18 : 22,
        fontWeight: MediaQuery.of(context).boldText ? FontWeight.w500 : FontWeight.w300,
        // fontStyle: items[1] == "ONI" ? FontStyle.italic : FontStyle.normal,
      ),
      textAlign: TextAlign.center,
    );
  }
}

class Time extends StatelessWidget {
  final Station station;

  Time({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival == null) {
      // Plecare
      return DepartureTime(
        station: station,
        firstStation: true,
      );
    }

    if (station.departure == null) {
      // Sosire
      return ArrivalTime(
        station: station,
        finalStation: true,
      );
    }

    return Row(
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        Text(
          "→",
          style: Theme.of(context).textTheme.bodyText2?.copyWith(
            fontSize: isSmallScreen(context) ? 18 : 22,
          ),
        ),
        Container(width: 2,),
        ArrivalTime(station: station,),
        Expanded(child: Container(),),
        StopTime(station: station,),
        Expanded(child: Container(),),
        DepartureTime(station: station,),
        Container(width: 2,),
        Text(
          "→",
          style: Theme.of(context).textTheme.bodyText2?.copyWith(
            fontSize: isSmallScreen(context) ? 18 : 22,
          ),
        ),
      ],
    );
  }
}

class ArrivalTime extends StatelessWidget {
  final Station station;
  final bool finalStation;

  ArrivalTime({
    required this.station,
    this.finalStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival == null) {
      return Container();
    }
    if (finalStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Text(
            "→",
            style: Theme.of(context).textTheme.bodyText2?.copyWith(
              fontSize: isSmallScreen(context) ? 18 : 22,
            ),
          ),
          Container(width: 2,),
          Text("sosire la "),
          ArrivalTime(station: station,),
          Expanded(child: Container(),),
        ],
      );
    }
    else {
      final delay = station.arrival!.status?.delay ?? 0;
      final time = DateTime.parse(station.arrival!.scheduleTime);

      if (delay == 0) {
        return Text("${time.hour.toString().padLeft(2, '0')}:${time.minute.toString().padLeft(2, '0')}");
      }
      else if (delay > 0) {
        final oldDate = time;
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.red.shade300,
              ),
            ),
          ],
        );
      }
      else {
        final oldDate = time;
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.green.shade300,
              ),
            ),
          ],
        );
      }
    }
  }
}

class StopTime extends StatelessWidget {
  final Station station;

  StopTime({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisSize: MainAxisSize.min,
      children: <Widget>[
        Text(
          "staționează pentru",
          textAlign: TextAlign.center,
        ),
        Builder(
          builder: (context) {
            int stopsForInt = station.stoppingTime!;
            bool minutes = false;
            if (stopsForInt >= 60) {
              stopsForInt ~/= 60;
              minutes = true;
            }
            if (stopsForInt == 1) {
              return Text(
                "1 " + (minutes ? 'minut' : 'secundă'),
                textAlign: TextAlign.center,
              );
            }
            else if (stopsForInt < 20) {
              return Text(
                "$stopsForInt ${minutes ? 'minute' : 'secunde'}",
                textAlign: TextAlign.center,
              );
            }
            else {
              return Text(
                "$stopsForInt de ${minutes ? 'minute' : 'secunde'}",
                textAlign: TextAlign.center,
              );
            }
          },
        )
      ],
    );
  }
}

class DepartureTime extends StatelessWidget {
  final Station station;
  final bool firstStation;

  DepartureTime({
    required this.station,
    this.firstStation = false,
  });

  @override
  Widget build(BuildContext context) {
    if (station.departure == null) {
      return Container();
    }
    if (firstStation) {
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Expanded(child: Container(),),
          Text("plecare la "),
          DepartureTime(station: station,),
          Container(width: 2,),
          Text(
            "→",
            style: Theme.of(context).textTheme.bodyText2?.copyWith(
              fontSize: 22,
            ),
          ),
        ],
      );
    }
    else {
      final delay = station.departure!.status?.delay ?? 0;
      final time = DateTime.parse(station.departure!.scheduleTime);

      if (delay == 0) {
        return Text("${time.hour.toString().padLeft(2, '0')}:${time.minute.toString().padLeft(2, '0')}");
      }
      else if (delay > 0) {
        final oldDate = time;
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.red.shade300,
              ),
            ),
          ],
        );
      }
      else {
        final oldDate = time;
        final newDate = oldDate.add(Duration(minutes: delay));

        return Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Text(
              "${oldDate.hour.toString().padLeft(2, '0')}:${oldDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                decoration: TextDecoration.lineThrough,
              ),
            ),
            Text(
              "${newDate.hour.toString().padLeft(2, '0')}:${newDate.minute.toString().padLeft(2, '0')}",
              style: Theme.of(context).textTheme.bodyText2?.copyWith(
                color: Colors.green.shade300,
              ),
            ),
          ],
        );
      }
    }
  }
}


class Delay extends StatelessWidget {
  final Station station;

  Delay({
    required this.station,
  });

  @override
  Widget build(BuildContext context) {
    if (station.arrival?.status == null && station.departure?.status == null) {
      return Container();
    }
    var delay = station.arrival?.status?.delay;
    if (station.departure?.status?.real == true) {
      delay = station.departure?.status?.delay;
    }

    if (delay == 0 || delay == null) return Container();
    else if (delay > 0) {
      return Text(
        "$delay ${delay == 1 ? 'minut' : 'minute'} întârziere",
        style: Theme.of(context).textTheme.bodyText2?.copyWith(
          color: Colors.red.shade300,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }
    else if (delay < 0) {
      return Text(
        "${-delay} ${delay == -1 ? 'minut' : 'minute'} mai devreme",
        style: Theme.of(context).textTheme.bodyText2?.copyWith(
          color: Colors.green.shade300,
          fontSize: 14,
          fontStyle: FontStyle.italic,
        ),
      );
    }

    return Container();
  }
}
